@@ -54,6 +54,11 @@ class ArtifactEntry:
         Path(local_path[:i_last_separator]).mkdir(parents=True, exist_ok=True)
 
         interface.download_file(self.path, artifact_id, local_path, team_name, exp_name, artifact_name, artifact_type, versioning, self.lfs_yn, self.repo_tag, file_index, total_file_count, self.size)
+        # 다운로드 후 파일의 digest 확인
+        with open(local_path, "rb") as f:
+            downloaded_file_digest = hashlib.md5(f.read()).hexdigest()
+        if self.digest != downloaded_file_digest:
+            raise Exception(f"file check sum error : checksum value are '{self.digest}' expected, but '{downloaded_file_digest}'")
 
         # 다운로드 완료 후 local_path 설정
         self.local_path = local_path
@@ -128,11 +133,14 @@ class Artifacts:
                         fd_names = fd_names[i:]
                         break
                 path = os.path.join(*fd_names)
+                if sys.platform.startswith('win32'):
+                    # 윈도우인 경우 Path Seperator를 리눅스 형식으로 강제로 변경함
+                    path = path.replace("\\", "/")
                 size = os.stat(local_path).st_size
                 with open(local_path,"rb") as f:
                     digest = hashlib.md5(f.read()).hexdigest()
 
-                entry = self.__find_entry_by_local_path(local_path)
+                entry = self.__find_entry_by_path(local_path, path)
                 if entry:
                     entry.status = "SYNC"   # 변경이 없는 경우
                 else:
@@ -145,8 +153,12 @@ class Artifacts:
                 if not os.path.isfile(entry.local_path):
                     entry.status = "DELETE"
 
-    def __find_entry_by_local_path(self, local_path:str) -> ArtifactEntry:
+    def __find_entry_by_path(self, local_path:str, path:str) -> ArtifactEntry:
         for entry in self.entry_list:
+            if not entry.local_path:  #download()를 실행하지 않은 경우 local_path가 ""이므로 entry.path에서 비교
+                if entry.path == path:
+                    return entry
+
             if entry.local_path == local_path:
                 return entry
         else:
