@@ -4,7 +4,7 @@ import json
 import os
 import sys
 from typing import Any, Dict, List, Tuple, TYPE_CHECKING
-
+from urllib.parse import urlparse
 import grpc
 
 from deepdriver import logger
@@ -47,6 +47,10 @@ def get_http_host() -> str:
     global http_host
     return http_host
 
+def get_http_host_ip() -> str:
+
+    global http_host
+    return urlparse(http_host).scheme
 
 def upload_config():
     pass
