@@ -91,13 +91,14 @@ def print_progress(iteration: int, total: int, prefix: str = 'Loading', suffix:
 
 from functools import wraps
 def login_required(original_function):
+    from deepdriver import logger
     ''' deepdriver 로그인 체크 '''
     @wraps(original_function)
     def wrapper(*args, **kwargs):
         from deepdriver.sdk.interface.interface import get_stub
         stub = get_stub()
         if not stub:
-            print("please log in first")
+            logger.info("please log in first")
             raise Exception("Login required.")
         return original_function(*args, **kwargs)
 
@@ -105,13 +106,14 @@ def login_required(original_function):
 
 
 def init_required(original_function):
+    from deepdriver import logger
     ''' deepdriver init() 체크 '''
     @wraps(original_function)
     def wrapper(*args, **kwargs):
         from deepdriver.sdk.data_types.run import get_run
         run = get_run()
         if not run:
-            print("please call deepdriver.init() first")
+            logger.info("please call deepdriver.init() first")
             raise Exception("Deepdriver not inited")
         return original_function(*args, **kwargs)
 
